Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/netbsd-1-6]: src/sys/dev/pci Pull up revision 1.8 (requested by 128 in t...



details:   https://anonhg.NetBSD.org/src/rev/87cb09a7bdb0
branches:  netbsd-1-6
changeset: 527801:87cb09a7bdb0
user:      tv <tv%NetBSD.org@localhost>
date:      Mon Jun 10 15:57:44 2002 +0000

description:
Pull up revision 1.8 (requested by 128 in ticket #0):
- mask IE_UpdateStats interrupt: the driver fails to clear the interrupt
  and enter an interrupt loop (it may be a chip bug, I didn't have the time
  to investigate yet) if it attemps to transmit some packets while the link
  is down (like unplug/replug the cable, ifconfig down/ifconfig up or after a
  transmit underrun condition, see below)
- bump the default transmit threshold to 1504 to avoid transmit underruns.
  The driver resets the chip after a transmit underrun condition, which
  makes the link go down for several seconds, which is unacceptable for
  a server usage (after bootup you'll get 10s of underruns before the
  threshold is high enouth and things stabilize, which means the link is
  almost unusable for minutes)
- update documentation to mention the quad-port DFE580TX, and mention the
  driver in notes.

diffstat:

 sys/dev/pci/if_ste.c |  19 +++++++++++++++----
 1 files changed, 15 insertions(+), 4 deletions(-)

diffs (50 lines):

diff -r bdb9249e515c -r 87cb09a7bdb0 sys/dev/pci/if_ste.c
--- a/sys/dev/pci/if_ste.c      Fri Jun 07 19:44:48 2002 +0000
+++ b/sys/dev/pci/if_ste.c      Mon Jun 10 15:57:44 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: if_ste.c,v 1.7 2001/11/13 07:48:44 lukem Exp $ */
+/*     $NetBSD: if_ste.c,v 1.7.10.1 2002/06/10 15:57:44 tv Exp $       */
 
 /*-
  * Copyright (c) 2001 The NetBSD Foundation, Inc.
@@ -42,7 +42,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_ste.c,v 1.7 2001/11/13 07:48:44 lukem Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_ste.c,v 1.7.10.1 2002/06/10 15:57:44 tv Exp $");
 
 #include "bpfilter.h"
 
@@ -504,9 +504,9 @@
        IFQ_SET_READY(&ifp->if_snd);
 
        /*
         * Default the transmit threshold to 128 bytes.
         */
-       sc->sc_txthresh = 128;
+       sc->sc_txthresh = 1504;
 
        /*
         * Disable MWI if the PCI layer tells us to.
@@ -1263,8 +1263,19 @@
        /*
         * Initialize the interrupt mask.
         */
+# if 0
        sc->sc_IntEnable = IE_HostError | IE_TxComplete | IE_UpdateStats |
            IE_TxDMAComplete | IE_RxDMAComplete;
+#else
+       /*
+        * On a Dlink DFE580-TX (DL-1002), attempting to transmit packets
+        * while the link is down cause the chip to create an IE_UpdateStats
+        * condition which can't be cleared, causing the driver to enter
+        * an interrupt loop. workaround: mask IE_UpdateStats
+        */
+       sc->sc_IntEnable = IE_HostError | IE_TxComplete | /*IE_UpdateStats |*/
+           IE_TxDMAComplete | IE_RxDMAComplete;
+#endif
        bus_space_write_2(st, sh, STE_IntStatus, 0xffff);
        bus_space_write_2(st, sh, STE_IntEnable, sc->sc_IntEnable);
 
@@ -504,9 +504,9 @@
 
        /*
-        * Default the transmit threshold to 128 bytes.
+        * Default the transmit threshold to 1504 bytes.
         */



Home | Main Index | Thread Index | Old Index